@@ -72,11 +72,11 @@ if os.path.exists(LOGO_PATH):
 
 # -- Generate API ------------------------------------------------------------
 sys.path.insert(0, os.path.abspath("."))
-import extend_docstrings  # noqa: E402
-from abbreviate_signature import abbreviate_signature  # noqa: E402
+from _extend_docstrings import insert_math  # noqa: E402
+from _relink_references import relink_references  # noqa: E402
 
-abbreviate_signature()
-extend_docstrings.insert_math()
+relink_references()
+insert_math()
 
 shutil.rmtree("api", ignore_errors=True)
 subprocess.call(
@@ -153,6 +153,13 @@ autodoc_default_options = {
         ]
     ),
 }
+autodoc_type_aliases = {
+    "BuilderReturnType": "ampform.dynamics.builder.BuilderReturnType",
+    "ParameterValue": "ampform.helicity.ParameterValue",
+    "RangeDefinition": "symplot.RangeDefinition",
+    "Slider": "symplot.Slider",
+}
+autodoc_typehints_format = "short"
 AUTODOC_INSERT_SIGNATURE_LINEBREAKS = False
 graphviz_output_format = "svg"
 html_copy_source = True  # needed for download notebook button
@@ -179,6 +186,7 @@ html_theme_options = {
     "launch_buttons": {
         "binderhub_url": "https://mybinder.org",
         "colab_url": "https://colab.research.google.com",
+        "deepnote_url": "https://deepnote.com",
         "notebook_interface": "jupyterlab",
         "thebe": True,
         "thebelab": True,
@@ -240,7 +248,7 @@ def get_version(package_name: str) -> str:
 
 intersphinx_mapping = {
     "attrs": (f"https://www.attrs.org/en/{get_version('attrs')}", None),
-    "compwa-org": ("https://compwa-org.readthedocs.io/en/stable", None),
+    "compwa-org": ("https://compwa-org.readthedocs.io", None),
     "ipywidgets": (
         f"https://ipywidgets.readthedocs.io/en/{get_version('ipywidgets')}",
         None,
@@ -279,6 +287,7 @@ copybutton_prompt_text = r">>> |\.\.\. "  # doctest
 linkcheck_anchors = False
 linkcheck_ignore = [
     "https://doi.org/10.1093/ptep/ptaa104",
+    "https://home.fnal.gov/~kutschke/Angdist/angdist.ps",
     "https://hss-opus.ub.ruhr-uni-bochum.de",
 ]
 
