@@ -34,16 +34,23 @@ class TwoBodyKinematicVariableSet:
     amplitude model.
     """
 
-    incoming_state_mass: sp.Symbol = attr.ib(instance_of(sp.Symbol))
-    outgoing_state_mass1: sp.Symbol = attr.ib(instance_of(sp.Symbol))
-    outgoing_state_mass2: sp.Symbol = attr.ib(instance_of(sp.Symbol))
-    helicity_theta: sp.Symbol = attr.ib(instance_of(sp.Symbol))
-    helicity_phi: sp.Symbol = attr.ib(instance_of(sp.Symbol))
+    incoming_state_mass: sp.Symbol = attr.ib(validator=instance_of(sp.Symbol))
+    outgoing_state_mass1: sp.Symbol = attr.ib(validator=instance_of(sp.Symbol))
+    outgoing_state_mass2: sp.Symbol = attr.ib(validator=instance_of(sp.Symbol))
+    helicity_theta: sp.Symbol = attr.ib(validator=instance_of(sp.Symbol))
+    helicity_phi: sp.Symbol = attr.ib(validator=instance_of(sp.Symbol))
     angular_momentum: Optional[int] = attr.ib(default=None)
 
 
 BuilderReturnType = Tuple[sp.Expr, Dict[sp.Symbol, float]]
-"""Type that a `.ResonanceDynamicsBuilder` should return."""
+"""Type that a `.ResonanceDynamicsBuilder` should return.
+
+The first element in this `tuple` is the `sympy.Expr <sympy.core.expr.Expr>`
+that describes the dynamics for the resonance. The second element are suggested
+parameter values (see :attr:`.parameter_defaults`) for the
+`~sympy.core.symbol.Symbol` instances that appear in the `sympy.Expr
+<sympy.core.expr.Expr>`.
+"""
 
 
 class ResonanceDynamicsBuilder(Protocol):
@@ -59,20 +66,21 @@ class ResonanceDynamicsBuilder(Protocol):
 
     def __call__(
         self, resonance: Particle, variable_pool: TwoBodyKinematicVariableSet
-    ) -> BuilderReturnType:
+    ) -> "BuilderReturnType":
+        """Formulate a dynamics `~sympy.core.expr.Expr` for this resonance."""
         ...
 
 
 def create_non_dynamic(
     resonance: Particle, variable_pool: TwoBodyKinematicVariableSet
-) -> BuilderReturnType:
+) -> "BuilderReturnType":
     # pylint: disable=unused-argument
     return (1, {})
 
 
 def create_non_dynamic_with_ff(
     resonance: Particle, variable_pool: TwoBodyKinematicVariableSet
-) -> BuilderReturnType:
+) -> "BuilderReturnType":
     """Generate (only) a Blatt-Weisskopf form factor for a two-body decay.
 
     Returns the `~sympy.functions.elementary.miscellaneous.sqrt` of a
@@ -100,38 +108,65 @@ def create_non_dynamic_with_ff(
     )
 
 
-def create_relativistic_breit_wigner(
-    resonance: Particle, variable_pool: TwoBodyKinematicVariableSet
-) -> BuilderReturnType:
-    """Create a `.relativistic_breit_wigner` for a two-body decay."""
-    inv_mass = variable_pool.incoming_state_mass
-    res_mass = sp.Symbol(f"m_{resonance.name}")
-    res_width = sp.Symbol(f"Gamma_{resonance.name}")
-    expression = relativistic_breit_wigner(
-        s=inv_mass ** 2,
-        mass0=res_mass,
-        gamma0=res_width,
-    )
-    parameter_defaults = {
-        res_mass: resonance.mass,
-        res_width: resonance.width,
-    }
-    return expression, parameter_defaults
+class RelativisticBreitWignerBuilder:
+    """Factory for building relativistic Breit-Wigner expressions.
 
+    The :meth:`__call__` of this builder complies with the
+    `.ResonanceDynamicsBuilder`, so instances of this class can be used in
+    :meth:`.set_dynamics`.
 
-def _make_relativistic_breit_wigner_with_ff(
-    phsp_factor: PhaseSpaceFactorProtocol,
-    docstring: str,
-) -> ResonanceDynamicsBuilder:
-    """Factory for `.relativistic_breit_wigner_with_ff`."""
+    Args:
+        form_factor: Formulate a relativistic Breit-Wigner function with form
+            factor, using :func:`.relativistic_breit_wigner_with_ff`. If set to
+            `False`, :meth:`__call__` builds a
+            :func:`.relativistic_breit_wigner` (_without_ form factor).
+        phsp_factor: A class that complies with the
+            `.PhaseSpaceFactorProtocol`. Defaults to `.PhaseSpaceFactor`.
+    """
 
-    def dynamics_builder(
+    def __init__(
+        self,
+        form_factor: bool = False,
+        phsp_factor: Optional[PhaseSpaceFactorProtocol] = None,
+    ) -> None:
+        if phsp_factor is None:
+            phsp_factor = PhaseSpaceFactor
+        self.__phsp_factor = phsp_factor
+        self.__with_form_factor = form_factor
+
+    def __call__(
+        self, resonance: Particle, variable_pool: TwoBodyKinematicVariableSet
+    ) -> "BuilderReturnType":
+        """Formulate a relativistic Breit-Wigner for this resonance."""
+        if self.__with_form_factor:
+            return self.__formulate_with_form_factor(resonance, variable_pool)
+        return self.__formulate(resonance, variable_pool)
+
+    @staticmethod
+    def __formulate(
         resonance: Particle, variable_pool: TwoBodyKinematicVariableSet
-    ) -> BuilderReturnType:
+    ) -> "BuilderReturnType":
+        inv_mass = variable_pool.incoming_state_mass
+        res_mass = sp.Symbol(f"m_{resonance.name}")
+        res_width = sp.Symbol(f"Gamma_{resonance.name}")
+        expression = relativistic_breit_wigner(
+            s=inv_mass ** 2,
+            mass0=res_mass,
+            gamma0=res_width,
+        )
+        parameter_defaults = {
+            res_mass: resonance.mass,
+            res_width: resonance.width,
+        }
+        return expression, parameter_defaults
+
+    def __formulate_with_form_factor(
+        self, resonance: Particle, variable_pool: TwoBodyKinematicVariableSet
+    ) -> "BuilderReturnType":
         if variable_pool.angular_momentum is None:
             raise ValueError(
-                "Angular momentum is not defined but is required in the form"
-                " factor!"
+                "Angular momentum is not defined but is required in the"
+                " form factor!"
             )
 
         inv_mass = variable_pool.incoming_state_mass
@@ -150,7 +185,7 @@ def _make_relativistic_breit_wigner_with_ff(
             m_b=product2_inv_mass,
             angular_momentum=angular_momentum,
             meson_radius=meson_radius,
-            phsp_factor=phsp_factor,
+            phsp_factor=self.__phsp_factor,
         )
         parameter_defaults = {
             res_mass: resonance.mass,
@@ -159,24 +194,38 @@ def _make_relativistic_breit_wigner_with_ff(
         }
         return expression, parameter_defaults
 
-    dynamics_builder.__doc__ = docstring
-    return dynamics_builder
 
+create_relativistic_breit_wigner = RelativisticBreitWignerBuilder(
+    form_factor=False
+).__call__
+"""
+Create a `.relativistic_breit_wigner` for a two-body decay.
 
-__DOCSTRING = (
-    "Create a `.relativistic_breit_wigner_with_ff` for a two-body decay."
-)
-create_relativistic_breit_wigner_with_ff = (
-    _make_relativistic_breit_wigner_with_ff(
-        phsp_factor=PhaseSpaceFactor,
-        docstring=__DOCSTRING,
-    )
-)
-create_analytic_breit_wigner = _make_relativistic_breit_wigner_with_ff(
+This is a convenience function for a `RelativisticBreitWignerBuilder` _without_
+form factor.
+"""
+
+create_relativistic_breit_wigner_with_ff = RelativisticBreitWignerBuilder(
+    form_factor=True,
+    phsp_factor=PhaseSpaceFactor,
+).__call__
+"""
+Create a `.relativistic_breit_wigner_with_ff` for a two-body decay.
+
+This is a convenience function for a `RelativisticBreitWignerBuilder` _with_
+form factor and a 'normal' `.PhaseSpaceFactor`.
+"""
+
+create_analytic_breit_wigner = RelativisticBreitWignerBuilder(
+    form_factor=True,
     phsp_factor=PhaseSpaceFactorAnalytic,
-    docstring="""
+).__call__
+"""
 Create a `.relativistic_breit_wigner_with_ff` with analytic continuation.
 
+This is a convenience function for a `RelativisticBreitWignerBuilder` _with_
+form factor and a 'analytic' phase space factor (see
+`.PhaseSpaceFactorAnalytic`).
+
 .. seealso:: :doc:`/usage/dynamics/analytic-continuation`.
-""",
-)
+"""
