@@ -9,7 +9,7 @@ from qrules.transition import State, StateTransition
 from ampform.kinematics import _assert_two_body_decay
 
 
-@attr.s(auto_attribs=True, frozen=True)
+@attr.frozen
 class StateWithID(State):
     """Extension of `~qrules.transition.State` that embeds the state ID."""
 
@@ -27,7 +27,7 @@ class StateWithID(State):
         )
 
 
-@attr.s(auto_attribs=True, frozen=True)
+@attr.frozen
 class TwoBodyDecay:
     """Two-body sub-decay in a `~qrules.transition.StateTransition`.
 
@@ -88,8 +88,8 @@ class TwoBodyDecay:
         if spin_magnitude.is_integer():
             return int(spin_magnitude)
         raise ValueError(
-            f"Spin magnitude ({spin_magnitude}) of single particle state cannot be"
-            f" used as the angular momentum as it is not integral!"
+            f"Spin magnitude ({spin_magnitude}) of single particle state"
+            " cannot be used as the angular momentum as it is not integral!"
         )
 
 
